@@ -82,7 +82,7 @@ class Tier(object):
             end_time = self.end_time
 
         if start_time >= end_time:
-            raise Exception('start_time is larger than or equals to end_time.')
+            raise Exception('start_time is later than or equals to end_time.')
 
         df = self.to_dataframe()
 
@@ -107,7 +107,7 @@ class Tier(object):
         return plot
 
     def get_point(self, by_target, by, strict=True, point_type=None):
-        """Get Point of the Tier with chosen method. \n If `strict` set to False, get the closest Point object to the target. If `point_type` set to \'larger\', find the closest larger Point; If `point_type` set to \'smaller\', find the closest smaller Point.\nSee `help(by)` for more information on the available methods. To change related parameters, use `parameters`."""
+        """Get Point of the Tier with chosen method. \nIf `strict` set to False, get the closest Point object to the target. If `point_type` set to \'later\', find the closest later Point; If `point_type` set to \'earlier\', find the closest earlier Point.\nSee `help(by)` for more information on the available methods. To change related parameters, use `parameters`."""
 
         if by not in _by.by_methods:
             raise Exception(
@@ -126,13 +126,13 @@ class Tier(object):
 
                 if point_type == None:
                     pass
-                elif point_type == 'larger':
+                elif point_type == 'later':
                     points = [point for point in points if point.time >= by_target]
-                elif point_type == 'smaller':
+                elif point_type == 'earlier':
                     points = [point for point in points if point.time <= by_target]
                 else:
                     raise Exception(
-                        '`point_type` can only by one of {\'larger\', \'smaller\', None}.'
+                        '`point_type` can only by one of {\'later\', \'earlier\', None}.'
                     )
 
                 points.sort(key=lambda point: abs(point.time - by_target))
@@ -242,7 +242,7 @@ class Tier(object):
         parameters['points.ignore_missing_point'] = False
 
         if by == _by.TIME and not strict:
-            points = self.get_point(min(by_target), by, strict=strict, point_type='smaller'), self.get_point(max(by_target), by, strict=strict, point_type='larger')
+            points = self.get_point(min(by_target), by, strict=strict, point_type='earlier'), self.get_point(max(by_target), by, strict=strict, point_type='later')
 
         else:
             points = self.get_point(
